zisk-sm-binary 1.1.0-alpha

Binary operations state machine for the ZisK zkVM
docs.rs failed to build zisk-sm-binary-1.1.0-alpha
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.